==> comedilib-0.7.3.tgz: comedilib-0.7.3/demo/info.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

void help(void)
{
	fprintf(stderr,"info </dev/comediN>\n");
	exit(0);
}

char *tobinary(char *s,int bits,int n);

char *subdevice_types[]={
	"unused",
	"analog input",
	"analog output",
	"digital input",
	"digital output",
	"digital I/O",
	"counter",
	"timer",
	"memory",
	"calibration",
	"processor"
};



int main(int argc,char *argv[])
{
	int i;
	comedi_t *it;
	int n_subdevices,type;
	
	if(argc!=2)help();

	it=comedi_open(argv[1]);
	if(!it){
		fprintf(stderr,"cannot open %s\n",argv[1]);
		exit(0);
	}

	printf("overall info:\n");
	printf("  version code: 0x%06x\n",comedi_get_version_code(it));
	printf("  driver name: %s\n",comedi_get_driver_name(it));
	printf("  board name: %s\n",comedi_get_board_name(it));
	printf("  number of subdevices: %d\n",n_subdevices=comedi_get_n_subdevices(it));
	
	for(i=0;i<n_subdevices;i++){
		printf("subdevice %d:\n",i);
		type=comedi_get_subdevice_type(it,i);
		printf("  type: %d (%s)\n",type,subdevice_types[type]);
		printf("  number of channels: %d\n",comedi_get_n_channels(it,i));
		printf("  max data value: %d\n",comedi_get_maxdata(it,i,0));
	}
#if 0
	for(i=0;i<info.chan;i++){
		printf("channel %d:\n",i);
		j=0;
		for(;;){
			param.chan=i;
			param.pnum=j;
			ret=ioctl(it,COMEDI_GETNPARAM,&param);
			if(ret<0)break;
			
			printf("   %-4.4s ",flagstring[param.flags]);
			switch(param.pnum){
			case COMEDI_IO:
				switch(param.pval){
				case COMEDI_IO_INPUT:
					printf("input");
					break;
				case COMEDI_IO_OUTPUT:
					printf("output");
					break;
				case COMEDI_IO_BIDIR:
					printf("bidirectional");
					break;
				default:
					printf("input/output unknown");
					break;
				}
				break;
			case COMEDI_AD:
				switch(param.pval){
				case COMEDI_AD_ANALOG:
					printf("analog");
					break;
				case COMEDI_AD_DIGITAL:
					printf("digital");
					break;
				default:
					printf("analog/digital unknown");
					break;
				}
				break;
			case COMEDI_BITS:
				printf("number of bits=%d",param.pval);
				break;
			case COMEDI_MAXDATA:
				printf("max data=%d",param.pval);
				break;
			case COMEDI_RANGE:
				printf("range=[%d]",param.pval);
				break;
			case COMEDI_LASTDATA:
				printf("last data=%d",param.pval);
				break;
			case COMEDI_LASTSEC:
				printf("last sec=%d",param.pval);
				break;
			case COMEDI_LASTNSEC:
				printf("last nsec=%d",param.pval);
				break;
			case COMEDI_AREF:
				printf("analog reference: ");
				switch(param.pval){
				case COMEDI_AREF_GND:
					printf("ground");
					break;
				case COMEDI_AREF_COM:
					printf("floating common");
					break;
				case COMEDI_AREF_DIFF:
					printf("differential");
					break;
				case COMEDI_AREF_OTHER:
					printf("other");
					break;
				default:
					printf("unknown");
					break;
				}
				break;
			case COMEDI_DITHER:
				printf(param.pval?"dither enabled"
					:"dither disabled");
				break;
			case COMEDI_DEGLITCH:
				printf(param.pval?"deglitch enabled"
					:"deglitch disabled");
				break;
			case COMEDI_STROBE:
				printf(param.pval?"strobe enabled"
					:"strobe disabled");
				break;
			case COMEDI_IOBITGROUP:
				printf("# of bits grouped for I/O determination: %d",
					param.pval);
				break;
			case COMEDI_IOBITS:
				printf("I/O bitfield (1=output): 0b%s",
					tobinary(s,param.pval,16));
				break;
			case COMEDI_COUNT:
				printf("counter value: %d\n",param.pval);
				break;
                        case COMEDI_RANGE_TYPE: {
                          comedi_range_info *range_info;
                          int k;
                          printf("ranges: ");
                          comedi_get_range_info(it, i, &range_info);
                          for (k = 0 ; k < range_info->n_ranges ; k++) {
                            printf("%s{%g:%g}",
                                   k?", ":"",
                                   range_info->range[k].min,
                                   range_info->range[k].max);
                          }
                        } break;
			default:
				printf("unknown %d",param.pval);
			}
			printf("\n");
			j++;
		}
	}
#endif
	
	return 0;
}

char *tobinary(char *s,int bits,int n)
{
	int bit=1<<n;
	char *t=s;
	
	for(;bit;bit>>=1)
		*t++=(bits&bit)?'1':'0';
	*t=0;
	
	return s;
}

==> comedilib-0.7.8.tgz: comedilib-0.7.8/demo/info.c <==
/*
   This demo reads information about a comedi device and
   displays the information in a human-readable form.
 */

#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

void help(void)
{
	fprintf(stderr,"info </dev/comediN>\n");
	exit(0);
}

char *tobinary(char *s,int bits,int n);

char *subdevice_types[]={
	"unused",
	"analog input",
	"analog output",
	"digital input",
	"digital output",
	"digital I/O",
	"counter",
	"timer",
	"memory",
	"calibration",
	"processor"
};

comedi_t *it;
extern char *filename;


int main(int argc,char *argv[])
{
	int i;
	int n_subdevices,type;
	
	parse_options(argc,argv);

	it=comedi_open(filename);
	if(!it){
		fprintf(stderr,"cannot open %s\n",filename);
		exit(0);
	}

	printf("overall info:\n");
	printf("  version code: 0x%06x\n",comedi_get_version_code(it));
	printf("  driver name: %s\n",comedi_get_driver_name(it));
	printf("  board name: %s\n",comedi_get_board_name(it));
	printf("  number of subdevices: %d\n",n_subdevices=comedi_get_n_subdevices(it));
	
	for(i=0;i<n_subdevices;i++){
		printf("subdevice %d:\n",i);
		type=comedi_get_subdevice_type(it,i);
		printf("  type: %d (%s)\n",type,subdevice_types[type]);
		printf("  number of channels: %d\n",comedi_get_n_channels(it,i));
		printf("  max data value: %d\n",comedi_get_maxdata(it,i,0));
	}
	
	return 0;
}

char *tobinary(char *s,int bits,int n)
{
	int bit=1<<n;
	char *t=s;
	
	for(;bit;bit>>=1)
		*t++=(bits&bit)?'1':'0';
	*t=0;
	
	return s;
}
